from .AnimeAvatar import AnimeAvatar
from .ArtAlbum import ArtAlbum
from .cosplay import CosPlay
from .CoupleAvatar import CoupleAvatar
from .FemaleAvatar import FemaleAvatar
from .Figure import Figure
from .hanfu import HanFu
from .jk import JK
from .lolita import Lolita
from .MaleAvatar import MaleAvatar
from .pcpic import PcPic
from .phonepic import PhonePic
from .SelectedIllustrations import SelectedIllustrations
from .SelectedPixiv import SelectedPixiv

__all__ = ['AnimeAvatar', 'ArtAlbum', 'CosPlay', 'CoupleAvatar', 'FemaleAvatar', 'Figure', 
            'HanFu', 'JK', 'Lolita', 'MaleAvatar', 'PcPic', 'PhonePic', 'SelectedIllustrations', 
            'SelectedPixiv']
__title__ = 'dimtown'
__description__ = 'A Spider for https://dimtown.com'
__url__ = 'https://github.com/Cvandia/dimtown-spider'
__version__ = '0.0.1'
__author__ = 'Cvandia'
__author_email__ = '1141538825@qq.com'
__license__ = 'MIT License'


from utils import Spider
from bs4 import BeautifulSoup
import httpx
import asyncio

class PcPic(Spider):
    
        def __init__(self) -> None:
            super().__init__()
            self.api_url = self.base_url + "bz"
    
        async def _save_html(self, file_name:str) -> bool:
            '''
            保存网页
            
            参数:
            - file_name: 文件名
            
            返回:
            - bool: 是否保存成功
            '''
            await super()._save_html(self.api_url, file_name)
    
        async def get_pcpic_list(self, page:int = 1) -> list:
            '''
            获取pc壁纸列表
            
            参数:
            - page: 页数
            
            返回:
            - list: pc壁纸列表
            '''
            return await super().get_img_list(page)
        
        async def get_pcpic_title(self, page:int = 1) -> list:
            '''
            获取pc壁纸标题
            
            参数:
            - page: 页数
            
            返回:
            - list: pc壁纸标题
            '''
            return await super().get_title_list(page)
    
        async def get_pcpic_img(self, url:str) -> list:
            '''
            获取pc壁纸图片列表
            
            参数:
            - url: pc壁纸链接
            
            返回:
            - list: pc壁纸图片列表
            '''
            return await super().get_img_url(url)



from utils import Spider
from bs4 import BeautifulSoup
import httpx
import asyncio

class ArtAlbum(Spider):
    
    def __init__(self) -> None:
        super().__init__()
        self.api_url = self.base_url + "tujihuace"

    async def _save_html(self, file_name:str) -> bool:
        await super()._save_html(self.api_url, file_name)

    async def get_artalbum_list(self, page:int = 1) -> list:
        '''
        获取画册列表
        
        参数:
        - page: 页数

        返回:
        - list: 画册列表
        '''
        return await super().get_img_list(page)
    
    async def get_artalbum_title(self, page:int = 1) -> list:
        '''
        获取画册标题
        
        参数:
        - page: 页数
        
        返回:
        - list: 画册标题
        '''
        return await super().get_title_list(page)

    async def get_artalbum_img(self, url:str) -> list:
        '''
        获取画册图片列表
        
        参数:
        - url: 画册链接
        
        返回:
        - list: 画册图片列表'''
        return await super().get_img_url(url)


from AnimeAvatar import AnimeAvatar
import asyncio

class MaleAvatar(AnimeAvatar):
    def __init__(self) -> None:
        super().__init__()
        self.api_url = self.base_url + "mantx"

    async def get_maleavatar_list(self, page:int = 1) -> list:
        '''
        获取男生头像列表
        
        参数:
        - page: 页数
        
        返回:
        - list: 男生头像列表
        '''
        return await super().get_img_list(page)
    
    async def get_maleavatar_title(self, page:int = 1) -> list:
        '''
        获取男生头像标题
        
        参数:
        - page: 页数
        
        返回:
        - list: 男生头像标题
        '''
        return await super().get_title_list(page)
    
    async def get_maleavatar_img(self, url:str) -> list:
        '''
        获取男生头像图片列表
        
        参数:
        - url: 男生头像链接
        
        返回:
        - list: 男生头像图片列表
        '''
        return await super().get_animeavatar_img(url)
    


from utils import Spider
import asyncio

class Figure(Spider):
    def __init__(self) -> None:
        super().__init__()
        self.api_url = self.base_url + "shouban"
    
    async def get_figure_list(self, page:int = 1) -> list:
        '''
        获取手办列表
        
        参数:
        - page: 页数
        
        返回:
        - list: 手办列表
        '''
        return await super().get_img_list(page)
    
    async def get_figure_title(self, page:int = 1) -> list:
        '''
        获取手办标题
        
        参数:
        - page: 页数
        
        返回:
        - list: 手办标题
        '''
        return await super().get_title_list(page)
    
    async def get_figure_img(self, url:str) -> list:
        '''
        获取手办图片列表
        
        参数:
        - url: 手办链接
        
        返回:
        - list: 手办图片列表
        '''
        return await super().get_img_url(url)
